@@ -20,7 +20,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/prctl.h>
-#include <sys/wait.h>
 #include <ctype.h>
 #include <libavcodec/avcodec.h>
 #include <libswscale/swscale.h>
@@ -77,6 +76,8 @@ int tc_client_in[2];
 const char* channel=0;
 const char* mycolor=0;
 char* nickname=0;
+char frombuild=0; // Running from the build directory
+#define TC_CLIENT (frombuild?"./tc_client":"tc_client")
 
 void updatescaling(struct viddata* data, unsigned int width, unsigned int height)
 {
@@ -190,7 +191,6 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
   }
   if(!strcmp(buf, "Password required"))
   {
-    wait(0); // Reap the previous process
     gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(data->gui, "main")));
     gtk_widget_show_all(GTK_WIDGET(gtk_builder_get_object(data->gui, "channelpasswordwindow")));
     return 1;
@@ -234,6 +234,8 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
         if(!offset){_exit(1);}
         offset[0]=0;
         offset=&offset[1];
+        char* end=strchr(offset, ' '); // Ignore any additional arguments after the offset (the modbot utility includes the video title here)
+        if(end){end[0]=0;}
         // Handle format string
         const char* fmt=config_get_str("youtubecmd");
         int len=strlen(fmt)+1;
@@ -452,6 +454,12 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
   {
     pos+=read(fd, pkt.data+pos, size-pos);
   }
+  if(!strcmp(&buf[7], "out"))
+  {
+    dprintf(tc_client_in[1], "/video %i\n", size+1);
+    write(tc_client_in[1], &frameinfo, 1);
+    write(tc_client_in[1], pkt.data, size);
+  }
   if((frameinfo&0xf)!=2){return 1;} // Not FLV1, get data but discard it
   if(!cam){printf("No cam found with ID '%s'\n", &buf[7]); return 1;}
   pkt.size=size;
@@ -500,10 +508,12 @@ void audiothread(int fd)
 
 #ifdef HAVE_V4L2
 pid_t camproc=0;
+unsigned int cameventsource;
 void togglecam(GtkCheckMenuItem* item, struct viddata* data)
 {
   if(!gtk_check_menu_item_get_active(item))
   {
+    g_source_remove(cameventsource);
     kill(camproc, SIGINT);
     camproc=0;
     dprintf(tc_client_in[1], "/camdown\n");
@@ -572,10 +582,7 @@ void togglecam(GtkCheckMenuItem* item, struct viddata* data)
 packet.size=0;
       avcodec_encode_video2(ctx, &packet, dstframe, &gotpacket);
       unsigned char frameinfo=0x22; // Note: differentiating between keyframes and non-keyframes seems to break stuff, so let's just go with all being interframes (1=keyframe, 2=interframe, 3=disposable interframe)
-      dprintf(tc_client_in[1], "/video %i\n", packet.size+1);
-      write(tc_client_in[1], &frameinfo, 1);
-      write(tc_client_in[1], packet.data, packet.size);
-      // Also send the packet to our main thread so we can see ourselves
+      // Send the packet to our main thread so we can see ourselves (the main thread also sends it to the server)
       dprintf(campipe[1], "Video: out %i\n", packet.size+1);
       write(campipe[1], &frameinfo, 1);
       write(campipe[1], packet.data, packet.size);
@@ -588,7 +595,7 @@ packet.size=0;
   close(campipe[1]);
   GIOChannel* channel=g_io_channel_unix_new(campipe[0]);
   g_io_channel_set_encoding(channel, 0, 0);
-  g_io_add_watch(channel, G_IO_IN, handledata, data);
+  cameventsource=g_io_add_watch(channel, G_IO_IN, handledata, data);
 }
 #endif
 
@@ -720,9 +727,9 @@ void startsession(GtkButton* button, struct viddata* data)
     dup2(tc_client_in[0], 0);
     if(acc_user[0])
     {
-      execl("./tc_client", "./tc_client", "-u", acc_user, channel, nick, chanpass, (char*)0);
+      execlp(TC_CLIENT, TC_CLIENT, "-u", acc_user, channel, nick, chanpass, (char*)0);
     }else{
-      execl("./tc_client", "./tc_client", channel, nick, chanpass, (char*)0);
+      execlp(TC_CLIENT, TC_CLIENT, channel, nick, chanpass, (char*)0);
     }
   }
   if(acc_user[0]){dprintf(tc_client_in[1], "%s\n", acc_pass);}
@@ -766,10 +773,12 @@ void startsession(GtkButton* button, struct viddata* data)
 
 int main(int argc, char** argv)
 {
+  if(!strncmp(argv[0], "./", 2)){frombuild=1;}
   struct viddata data={0,0,0,0,0};
   avcodec_register_all();
   data.vdecoder=avcodec_find_decoder(AV_CODEC_ID_FLV1);
   data.adecoder=avcodec_find_decoder(AV_CODEC_ID_NELLYMOSER);
+  signal(SIGCHLD, SIG_IGN);
 
 #if defined(HAVE_AVRESAMPLE) || defined(HAVE_SWRESAMPLE)
   #ifdef HAVE_AVRESAMPLE
@@ -800,7 +809,13 @@ int main(int argc, char** argv)
 #endif
 
   gtk_init(&argc, &argv);
-  GtkBuilder* gui=gtk_builder_new_from_file("gtkgui.glade");
+  GtkBuilder* gui;
+  if(frombuild)
+  {
+    gui=gtk_builder_new_from_file("gtkgui.glade");
+  }else{
+    gui=gtk_builder_new_from_file(PREFIX "/share/tc_client/gtkgui.glade");
+  }
   gtk_builder_connect_signals(gui, 0);
   data.gui=gui;
 
