@@ -35,6 +35,7 @@ struct list goodvids={0,0}; // pre-approved videos
 struct list badvids={0,0}; // not allowed, essentially banned
 char* playing=0;
 char* requester=0;
+char* title=0;
 time_t started=0;
 int tc_client;
 
@@ -135,13 +136,14 @@ unsigned int getduration(const char* vid)
 }
 
 unsigned int waitskip=0;
+time_t waitskiptime=0;
 void playnextvid()
 {
   waitskip=0;
   playing=queue.items[0].video;
   requester=queue.items[0].requester;
+  title=queue.items[0].title;
   say(0, "/mbs youTube %s 0 %s\n", playing, queue.items[0].title);
-  free(queue.items[0].title);
   --queue.itemcount;
   memmove(queue.items, &queue.items[1], sizeof(struct queueitem)*queue.itemcount);
   // Find out the video's length and schedule an alarm for then
@@ -153,8 +155,10 @@ void playnext(int x)
 {
   free(playing);
   free(requester);
+  free(title);
   playing=0;
   requester=0;
+  title=0;
   if(queue.itemcount<1){alarm(0); printf("Nothing more to play\n"); return;} // Nothing more to play
   if(!list_contains(&goodvids, queue.items[0].video))
   {
@@ -167,12 +171,14 @@ void playnext(int x)
         if(list_contains(&goodvids, queue.items[i].video))
         {
           waitskip=i;
+          waitskiptime=time(0)+120;
           alarm(120);
           break;
         }
       }
       return;
     }else{
+      if(time(0)<waitskiptime){return;} // Not time yet
       say(0, "Skipping http://youtube.com/watch?v=%s because it is still not approved after 2 minutes\n", queue.items[0].video);
       queue_movetofront(&queue, waitskip);
       waitskip=0;
@@ -224,7 +230,7 @@ int main(int argc, char** argv)
              "-l/--log <file> = log output into <file>\n"
              "-v/--verbose    = print/log all incoming messages\n"
              "\n");
-      execv("./tc_client", argv);
+      execvp(strncmp(argv[0], "./", 2)?"tc_client":"./tc_client", argv);
       return 1;
     }
   }
@@ -238,7 +244,7 @@ int main(int argc, char** argv)
     close(out[0]);
     dup2(in[0], 0);
     dup2(out[1], 1);
-    execv("./tc_client", argv);
+    execvp(strncmp(argv[0], "./", 2)?"tc_client":"./tc_client", argv);
     _exit(1);
   }
   close(in[0]);
@@ -389,7 +395,7 @@ int main(int argc, char** argv)
               say(pm, "Video '%s' (%s) is added to the queue but will need to be approved by a mod\n", vid, title);
             }
           }
-          else if(!playing){playnext(0);}
+          else if(!playing && !waitskip){playnext(0);}
           else{say(pm, "Added '%s' to queue, it has already been approved\n", title);}
         }
         // Undo
@@ -464,7 +470,7 @@ int main(int argc, char** argv)
         else if(!strcmp(msg, "!requestedby"))
         {
           if(!playing){say(pm, "Nothing is playing\n");}
-          else{say(pm, "%s requested %s\n", requester, playing);}
+          else{say(pm, "%s requested %s (%s)\n", requester, playing, title);}
         }
         else if(!strcmp(msg, "!time")) // Debugging
         {
@@ -509,6 +515,11 @@ int main(int argc, char** argv)
             say(pm, "Nothing is playing\n");
           }
         }
+        else if(!strcmp(msg, "!nowplaying"))
+        {
+          if(!playing){say(pm, "Nothing is playing\n");}
+          else{say(pm, "Currently playing: %s (http://youtube.com/watch?v=%s )\n", title, playing);}
+        }
         else if(list_contains(&mods, nick)) // Mods-only commands
         {
           if(!strcmp(msg, "!playnext"))
@@ -598,9 +609,12 @@ int main(int argc, char** argv)
             list_add(&badvids, vid);
             list_save(&goodvids, "goodvids.txt");
             list_save(&badvids, "badvids.txt");
-            if(playing && !strcmp(vid, playing)){say(0, "/mbc youTube\n");}
             say(pm, "Marked '%s' as bad, it will not be allowed into the queue again. You can reverse this by !approve'ing the video by ID/link/name\n", vid);
-            playnext(0);
+            if(playing && !strcmp(vid, playing))
+            {
+              say(0, "/mbc youTube\n");
+              playnext(0);
+            }
           }
           else if(!strcmp(msg, "!skip") || !strncmp(msg, "!skip ", 6))
           {
